# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dataproc/manager/v1/job_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dataproc/manager/v1/job_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.dataproc.manager.v1 import job_pb2 as yandex_dot_cloud_dot_dataproc_dot_manager_dot_v1_dot_job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/dataproc/manager/v1/job_service.proto\x12 yandex.cloud.dataproc.manager.v1\x1a\x1dyandex/cloud/validation.proto\x1a*yandex/cloud/dataproc/manager/v1/job.proto\"\x89\x01\n\x0fListJobsRequest\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"`\n\x10ListJobsResponse\x12\x33\n\x04jobs\x18\x01 \x03(\x0b\x32%.yandex.cloud.dataproc.manager.v1.Job\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdb\x01\n\x16UpdateJobStatusRequest\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x06job_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12<\n\x06status\x18\x03 \x01(\x0e\x32,.yandex.cloud.dataproc.manager.v1.Job.Status\x12K\n\x10\x61pplication_info\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.dataproc.manager.v1.ApplicationInfo\"\x19\n\x17UpdateJobStatusResponse\"n\n\x17ListSupportJobsResponse\x12:\n\x04jobs\x18\x01 \x03(\x0b\x32,.yandex.cloud.dataproc.manager.v1.SupportJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9c\x01\n\x1dUpdateSupportJobStatusRequest\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x06job_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x43\n\x06status\x18\x03 \x01(\x0e\x32\x33.yandex.cloud.dataproc.manager.v1.SupportJob.Status\"b\n\x18SaveSupportJobLogRequest\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x18\n\x06job_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x0e\n\x06output\x18\x03 \x01(\t\"\x1b\n\x19SaveSupportJobLogResponse2\xb5\x05\n\nJobService\x12u\n\nListActive\x12\x31.yandex.cloud.dataproc.manager.v1.ListJobsRequest\x1a\x32.yandex.cloud.dataproc.manager.v1.ListJobsResponse\"\x00\x12\x85\x01\n\x0cUpdateStatus\x12\x38.yandex.cloud.dataproc.manager.v1.UpdateJobStatusRequest\x1a\x39.yandex.cloud.dataproc.manager.v1.UpdateJobStatusResponse\"\x00\x12\x83\x01\n\x11ListSupportActive\x12\x31.yandex.cloud.dataproc.manager.v1.ListJobsRequest\x1a\x39.yandex.cloud.dataproc.manager.v1.ListSupportJobsResponse\"\x00\x12\x93\x01\n\x13UpdateSupportStatus\x12?.yandex.cloud.dataproc.manager.v1.UpdateSupportJobStatusRequest\x1a\x39.yandex.cloud.dataproc.manager.v1.UpdateJobStatusResponse\"\x00\x12\x8b\x01\n\x0eSaveSupportLog\x12:.yandex.cloud.dataproc.manager.v1.SaveSupportJobLogRequest\x1a;.yandex.cloud.dataproc.manager.v1.SaveSupportJobLogResponse\"\x00\x42}\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_managerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.manager.v1.job_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_manager'
  _globals['_LISTJOBSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_UPDATEJOBSTATUSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEJOBSTATUSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATEJOBSTATUSREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_UPDATEJOBSTATUSREQUEST'].fields_by_name['job_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATESUPPORTJOBSTATUSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATESUPPORTJOBSTATUSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATESUPPORTJOBSTATUSREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_UPDATESUPPORTJOBSTATUSREQUEST'].fields_by_name['job_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SAVESUPPORTJOBLOGREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_SAVESUPPORTJOBLOGREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_SAVESUPPORTJOBLOGREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_SAVESUPPORTJOBLOGREQUEST'].fields_by_name['job_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTJOBSREQUEST']._serialized_start=164
  _globals['_LISTJOBSREQUEST']._serialized_end=301
  _globals['_LISTJOBSRESPONSE']._serialized_start=303
  _globals['_LISTJOBSRESPONSE']._serialized_end=399
  _globals['_UPDATEJOBSTATUSREQUEST']._serialized_start=402
  _globals['_UPDATEJOBSTATUSREQUEST']._serialized_end=621
  _globals['_UPDATEJOBSTATUSRESPONSE']._serialized_start=623
  _globals['_UPDATEJOBSTATUSRESPONSE']._serialized_end=648
  _globals['_LISTSUPPORTJOBSRESPONSE']._serialized_start=650
  _globals['_LISTSUPPORTJOBSRESPONSE']._serialized_end=760
  _globals['_UPDATESUPPORTJOBSTATUSREQUEST']._serialized_start=763
  _globals['_UPDATESUPPORTJOBSTATUSREQUEST']._serialized_end=919
  _globals['_SAVESUPPORTJOBLOGREQUEST']._serialized_start=921
  _globals['_SAVESUPPORTJOBLOGREQUEST']._serialized_end=1019
  _globals['_SAVESUPPORTJOBLOGRESPONSE']._serialized_start=1021
  _globals['_SAVESUPPORTJOBLOGRESPONSE']._serialized_end=1048
  _globals['_JOBSERVICE']._serialized_start=1051
  _globals['_JOBSERVICE']._serialized_end=1744
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/raw_logs_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/raw_logs_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import raw_logs_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_raw__logs__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/cdn/v1/raw_logs_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/cdn/v1/raw_logs.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"s\n\x16\x41\x63tivateRawLogsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\".\n\x17\x41\x63tivateRawLogsMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"\x85\x01\n\x17\x41\x63tivateRawLogsResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".yandex.cloud.cdn.v1.RawLogsStatus\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\"=\n\x18\x44\x65\x61\x63tivateRawLogsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"0\n\x19\x44\x65\x61\x63tivateRawLogsMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"6\n\x11GetRawLogsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x80\x01\n\x12GetRawLogsResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".yandex.cloud.cdn.v1.RawLogsStatus\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\"q\n\x14UpdateRawLogsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\"\x83\x01\n\x15UpdateRawLogsResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".yandex.cloud.cdn.v1.RawLogsStatus\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\",\n\x15UpdateRawLogsMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t2\xba\x05\n\x0eRawLogsService\x12\xb5\x01\n\x08\x41\x63tivate\x12+.yandex.cloud.cdn.v1.ActivateRawLogsRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*2\n\x17\x41\x63tivateRawLogsMetadata\x12\x17\x41\x63tivateRawLogsResponse\x82\xd3\xe4\x93\x02\x1d\"\x18/cdn/v1/rawLogs:activate:\x01*\x12\xbb\x01\n\nDeactivate\x12-.yandex.cloud.cdn.v1.DeactivateRawLogsRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*2\n\x19\x44\x65\x61\x63tivateRawLogsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f\"\x1d/cdn/v1/rawLogs/{resource_id}\x12}\n\x03Get\x12&.yandex.cloud.cdn.v1.GetRawLogsRequest\x1a\'.yandex.cloud.cdn.v1.GetRawLogsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cdn/v1/rawLogs/{resource_id}\x12\xb2\x01\n\x06Update\x12).yandex.cloud.cdn.v1.UpdateRawLogsRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*.\n\x15UpdateRawLogsMetadata\x12\x15UpdateRawLogsResponse\x82\xd3\xe4\x93\x02\"2\x1d/cdn/v1/rawLogs/{resource_id}:\x01*BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.raw_logs_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_ACTIVATERAWLOGSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_ACTIVATERAWLOGSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DEACTIVATERAWLOGSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DEACTIVATERAWLOGSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETRAWLOGSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETRAWLOGSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERAWLOGSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERAWLOGSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RAWLOGSSERVICE'].methods_by_name['Activate']._loaded_options = None
  _globals['_RAWLOGSSERVICE'].methods_by_name['Activate']._serialized_options = b'\262\322*2\n\027ActivateRawLogsMetadata\022\027ActivateRawLogsResponse\202\323\344\223\002\035\"\030/cdn/v1/rawLogs:activate:\001*'
  _globals['_RAWLOGSSERVICE'].methods_by_name['Deactivate']._loaded_options = None
  _globals['_RAWLOGSSERVICE'].methods_by_name['Deactivate']._serialized_options = b'\262\322*2\n\031DeactivateRawLogsMetadata\022\025google.protobuf.Empty\202\323\344\223\002\037\"\035/cdn/v1/rawLogs/{resource_id}'
  _globals['_RAWLOGSSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RAWLOGSSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/cdn/v1/rawLogs/{resource_id}'
  _globals['_RAWLOGSSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RAWLOGSSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*.\n\025UpdateRawLogsMetadata\022\025UpdateRawLogsResponse\202\323\344\223\002\"2\035/cdn/v1/rawLogs/{resource_id}:\001*'
  _globals['_ACTIVATERAWLOGSREQUEST']._serialized_start=238
  _globals['_ACTIVATERAWLOGSREQUEST']._serialized_end=353
  _globals['_ACTIVATERAWLOGSMETADATA']._serialized_start=355
  _globals['_ACTIVATERAWLOGSMETADATA']._serialized_end=401
  _globals['_ACTIVATERAWLOGSRESPONSE']._serialized_start=404
  _globals['_ACTIVATERAWLOGSRESPONSE']._serialized_end=537
  _globals['_DEACTIVATERAWLOGSREQUEST']._serialized_start=539
  _globals['_DEACTIVATERAWLOGSREQUEST']._serialized_end=600
  _globals['_DEACTIVATERAWLOGSMETADATA']._serialized_start=602
  _globals['_DEACTIVATERAWLOGSMETADATA']._serialized_end=650
  _globals['_GETRAWLOGSREQUEST']._serialized_start=652
  _globals['_GETRAWLOGSREQUEST']._serialized_end=706
  _globals['_GETRAWLOGSRESPONSE']._serialized_start=709
  _globals['_GETRAWLOGSRESPONSE']._serialized_end=837
  _globals['_UPDATERAWLOGSREQUEST']._serialized_start=839
  _globals['_UPDATERAWLOGSREQUEST']._serialized_end=952
  _globals['_UPDATERAWLOGSRESPONSE']._serialized_start=955
  _globals['_UPDATERAWLOGSRESPONSE']._serialized_end=1086
  _globals['_UPDATERAWLOGSMETADATA']._serialized_start=1088
  _globals['_UPDATERAWLOGSMETADATA']._serialized_end=1132
  _globals['_RAWLOGSSERVICE']._serialized_start=1135
  _globals['_RAWLOGSSERVICE']._serialized_end=1833
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    name: builtins.str
    """User name"""
    password: builtins.str
    """User password. Used only in create and update requests"""
    resource_group: builtins.str
    """Resource group for user's queries"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        resource_group: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "password", b"password", "resource_group", b"resource_group"]) -> None: ...

global___User = User



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadbalancer.v1.network_load_balancer_pb2
import yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class NetworkLoadBalancerServiceStub:
    """A set of methods for managing NetworkLoadBalancer resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetNetworkLoadBalancerRequest,
        yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.NetworkLoadBalancer,
    ]
    """Returns the specified NetworkLoadBalancer resource.

    Get the list of available NetworkLoadBalancer resources by making a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancersRequest,
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancersResponse,
    ]
    """Retrieves the list of NetworkLoadBalancer resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.CreateNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a network load balancer in the specified folder using the data specified in the request."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.UpdateNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified network load balancer."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DeleteNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified network load balancer."""

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.StartNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts load balancing and health checking with the specified network load balancer with specified settings.
    Changes network load balancer status to `` ACTIVE ``.
    """

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.StopNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops load balancing and health checking with the specified network load balancer.
    Changes load balancer status to `` STOPPED ``.
    """

    AttachTargetGroup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.AttachNetworkLoadBalancerTargetGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches a target group to the specified network load balancer."""

    DetachTargetGroup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DetachNetworkLoadBalancerTargetGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches the target group from the specified network load balancer."""

    GetTargetStates: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetTargetStatesRequest,
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetTargetStatesResponse,
    ]
    """Gets states of target resources in the attached target group."""

    AddListener: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.AddNetworkLoadBalancerListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a listener to the specified network load balancer."""

    RemoveListener: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.RemoveNetworkLoadBalancerListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes the listener from the specified network load balancer."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancerOperationsRequest,
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancerOperationsResponse,
    ]
    """Lists operations for the specified network load balancer."""

    DisableZones: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DisableZonesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disable zones for the specified network load balancer."""

    EnableZones: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.EnableZonesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enable zones for the specified network load balancer."""

class NetworkLoadBalancerServiceAsyncStub:
    """A set of methods for managing NetworkLoadBalancer resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetNetworkLoadBalancerRequest,
        yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.NetworkLoadBalancer,
    ]
    """Returns the specified NetworkLoadBalancer resource.

    Get the list of available NetworkLoadBalancer resources by making a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancersRequest,
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancersResponse,
    ]
    """Retrieves the list of NetworkLoadBalancer resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.CreateNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a network load balancer in the specified folder using the data specified in the request."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.UpdateNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified network load balancer."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DeleteNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified network load balancer."""

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.StartNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts load balancing and health checking with the specified network load balancer with specified settings.
    Changes network load balancer status to `` ACTIVE ``.
    """

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.StopNetworkLoadBalancerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops load balancing and health checking with the specified network load balancer.
    Changes load balancer status to `` STOPPED ``.
    """

    AttachTargetGroup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.AttachNetworkLoadBalancerTargetGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches a target group to the specified network load balancer."""

    DetachTargetGroup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DetachNetworkLoadBalancerTargetGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches the target group from the specified network load balancer."""

    GetTargetStates: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetTargetStatesRequest,
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetTargetStatesResponse,
    ]
    """Gets states of target resources in the attached target group."""

    AddListener: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.AddNetworkLoadBalancerListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a listener to the specified network load balancer."""

    RemoveListener: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.RemoveNetworkLoadBalancerListenerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes the listener from the specified network load balancer."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancerOperationsRequest,
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancerOperationsResponse,
    ]
    """Lists operations for the specified network load balancer."""

    DisableZones: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DisableZonesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disable zones for the specified network load balancer."""

    EnableZones: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.EnableZonesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enable zones for the specified network load balancer."""

class NetworkLoadBalancerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing NetworkLoadBalancer resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetNetworkLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.NetworkLoadBalancer, collections.abc.Awaitable[yandex.cloud.loadbalancer.v1.network_load_balancer_pb2.NetworkLoadBalancer]]:
        """Returns the specified NetworkLoadBalancer resource.

        Get the list of available NetworkLoadBalancer resources by making a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancersResponse, collections.abc.Awaitable[yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancersResponse]]:
        """Retrieves the list of NetworkLoadBalancer resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.CreateNetworkLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a network load balancer in the specified folder using the data specified in the request."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.UpdateNetworkLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified network load balancer."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DeleteNetworkLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified network load balancer."""

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.StartNetworkLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts load balancing and health checking with the specified network load balancer with specified settings.
        Changes network load balancer status to `` ACTIVE ``.
        """

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.StopNetworkLoadBalancerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops load balancing and health checking with the specified network load balancer.
        Changes load balancer status to `` STOPPED ``.
        """

    @abc.abstractmethod
    def AttachTargetGroup(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.AttachNetworkLoadBalancerTargetGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Attaches a target group to the specified network load balancer."""

    @abc.abstractmethod
    def DetachTargetGroup(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DetachNetworkLoadBalancerTargetGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Detaches the target group from the specified network load balancer."""

    @abc.abstractmethod
    def GetTargetStates(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetTargetStatesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetTargetStatesResponse, collections.abc.Awaitable[yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.GetTargetStatesResponse]]:
        """Gets states of target resources in the attached target group."""

    @abc.abstractmethod
    def AddListener(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.AddNetworkLoadBalancerListenerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a listener to the specified network load balancer."""

    @abc.abstractmethod
    def RemoveListener(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.RemoveNetworkLoadBalancerListenerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes the listener from the specified network load balancer."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancerOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancerOperationsResponse, collections.abc.Awaitable[yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.ListNetworkLoadBalancerOperationsResponse]]:
        """Lists operations for the specified network load balancer."""

    @abc.abstractmethod
    def DisableZones(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.DisableZonesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Disable zones for the specified network load balancer."""

    @abc.abstractmethod
    def EnableZones(
        self,
        request: yandex.cloud.loadbalancer.v1.network_load_balancer_service_pb2.EnableZonesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Enable zones for the specified network load balancer."""

def add_NetworkLoadBalancerServiceServicer_to_server(servicer: NetworkLoadBalancerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.clouddesktop.v1.desktop_image_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListDesktopImagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list desktop images in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDesktopImagesRequest.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDesktopImagesRequest.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [DesktopImage.name] field.
    2. An operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.
    3. Value or a list of values to compare against the values of the field.
    """
    order_by: builtins.str
    """Sorting the list by [DesktopImage.name], [DesktopImage.created_at] and [DesktopImage.status] fields.
    The default sorting order is ascending.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDesktopImagesRequest = ListDesktopImagesRequest

@typing.final
class ListDesktopImagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_IMAGES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDesktopImagesRequest.page_size], use
    the [next_page_token] as the value
    for the [ListDesktopImagesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def desktop_images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.clouddesktop.v1.desktop_image_pb2.DesktopImage]:
        """List of desktop images."""

    def __init__(
        self,
        *,
        desktop_images: collections.abc.Iterable[yandex.cloud.clouddesktop.v1.desktop_image_pb2.DesktopImage] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_images", b"desktop_images", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDesktopImagesResponse = ListDesktopImagesResponse

@typing.final
class CopyDesktopImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to copy the image to."""
    name: builtins.str
    """Name of the image."""
    image_id: builtins.str
    """ID of the compute image to copy the image from."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "image_id", b"image_id", "name", b"name"]) -> None: ...

global___CopyDesktopImageRequest = CopyDesktopImageRequest

@typing.final
class UpdateDesktopImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """Id of image to update."""
    name: builtins.str
    """New desktop image name."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Mask of fields that need to be update."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New desktop image labels."""

    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateDesktopImageRequest = UpdateDesktopImageRequest

@typing.final
class CopyFromDesktopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESKTOP_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to copy the image to."""
    name: builtins.str
    """Name of the image."""
    desktop_id: builtins.str
    """ID of the desktop to copy the image from."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "folder_id", b"folder_id", "name", b"name"]) -> None: ...

global___CopyFromDesktopRequest = CopyFromDesktopRequest

@typing.final
class CopyDesktopImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the new image."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___CopyDesktopImageMetadata = CopyDesktopImageMetadata

@typing.final
class CopyFromDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the new image."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___CopyFromDesktopMetadata = CopyFromDesktopMetadata

@typing.final
class DeleteDesktopImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image to delete."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___DeleteDesktopImageRequest = DeleteDesktopImageRequest

@typing.final
class DeleteDesktopImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image to delete."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___DeleteDesktopImageMetadata = DeleteDesktopImageMetadata

@typing.final
class GetDesktopImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image to get."""
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___GetDesktopImageRequest = GetDesktopImageRequest

@typing.final
class UpdateDesktopImageMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id"]) -> None: ...

global___UpdateDesktopImageMetadata = UpdateDesktopImageMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/thumbnail_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/thumbnail_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import thumbnail_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_thumbnail__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/video/v1/thumbnail_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a%yandex/cloud/video/v1/thumbnail.proto\"9\n\x13GetThumbnailRequest\x12\"\n\x0cthumbnail_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xcd\x01\n\x14ListThumbnailRequest\x12\x1c\n\nchannel_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\nepisode_id\x18\xeb\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\x08video_id\x18\xec\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x1f\n\npage_token\x18\x65 \x01(\tB\x0b\x8a\xc8\x31\x07<=15000B\x0b\n\tparent_idJ\x04\x08\x02\x10\x64J\x05\x08\x66\x10\xeb\x07\"l\n\x15ListThumbnailResponse\x12\x34\n\nthumbnails\x18\x01 \x03(\x0b\x32 .yandex.cloud.video.v1.Thumbnail\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\x8a\x01\n\x16\x43reateThumbnailRequest\x12\x1c\n\nchannel_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\nepisode_id\x18\xeb\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\x08video_id\x18\xec\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x42\x0b\n\tparent_idJ\x05\x08\x02\x10\xeb\x07\"/\n\x17\x43reateThumbnailMetadata\x12\x14\n\x0cthumbnail_id\x18\x01 \x01(\t\"n\n BatchGenerateDownloadURLsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\rthumbnail_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\"g\n!BatchGenerateDownloadURLsResponse\x12\x42\n\rdownload_urls\x18\x01 \x03(\x0b\x32+.yandex.cloud.video.v1.ThumbnailDownloadURL\"\xe0\x02\n\x14ThumbnailDownloadURL\x12\x14\n\x0cthumbnail_id\x18\x01 \x01(\t\x12\x14\n\x0coriginal_url\x18\x02 \x01(\t\x12J\n\x0bscaled_urls\x18\x03 \x03(\x0b\x32\x35.yandex.cloud.video.v1.ThumbnailDownloadURL.ScaledURL\x1a\x8e\x01\n\tScaledURL\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tmax_width\x18\x02 \x01(\x03\x12\x12\n\nmax_height\x18\x03 \x01(\x03\x12M\n\x0cimage_format\x18\x04 \x01(\x0e\x32\x37.yandex.cloud.video.v1.ThumbnailDownloadURL.ImageFormat\"?\n\x0bImageFormat\x12\x1c\n\x18IMAGE_FORMAT_UNSPECIFIED\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x08\n\x04WEBP\x10\x02\"G\n!GenerateThumbnailUploadURLRequest\x12\"\n\x0cthumbnail_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"8\n\"GenerateThumbnailUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\"<\n\x16\x44\x65leteThumbnailRequest\x12\"\n\x0cthumbnail_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"/\n\x17\x44\x65leteThumbnailMetadata\x12\x14\n\x0cthumbnail_id\x18\x01 \x01(\t2\x93\x08\n\x10ThumbnailService\x12\x80\x01\n\x03Get\x12*.yandex.cloud.video.v1.GetThumbnailRequest\x1a .yandex.cloud.video.v1.Thumbnail\"+\x82\xd3\xe4\x93\x02%\x12#/video/v1/thumbnails/{thumbnail_id}\x12\x7f\n\x04List\x12+.yandex.cloud.video.v1.ListThumbnailRequest\x1a,.yandex.cloud.video.v1.ListThumbnailResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/video/v1/thumbnails\x12\xa3\x01\n\x06\x43reate\x12-.yandex.cloud.video.v1.CreateThumbnailRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*$\n\x17\x43reateThumbnailMetadata\x12\tThumbnail\x82\xd3\xe4\x93\x02\x19\"\x14/video/v1/thumbnails:\x01*\x12\xc9\x01\n\x19\x42\x61tchGenerateDownloadURLs\x12\x37.yandex.cloud.video.v1.BatchGenerateDownloadURLsRequest\x1a\x38.yandex.cloud.video.v1.BatchGenerateDownloadURLsResponse\"9\x82\xd3\xe4\x93\x02\x33\"./video/v1/thumbnails:batchGenerateDownloadURLs:\x01*\x12\xca\x01\n\x11GenerateUploadURL\x12\x38.yandex.cloud.video.v1.GenerateThumbnailUploadURLRequest\x1a\x39.yandex.cloud.video.v1.GenerateThumbnailUploadURLResponse\"@\x82\xd3\xe4\x93\x02:\"5/video/v1/thumbnails/{thumbnail_id}:generateUploadURL:\x01*\x12\xbb\x01\n\x06\x44\x65lete\x12-.yandex.cloud.video.v1.DeleteThumbnailRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*0\n\x17\x44\x65leteThumbnailMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/video/v1/thumbnails/{thumbnail_id}B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.thumbnail_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_GETTHUMBNAILREQUEST'].fields_by_name['thumbnail_id']._loaded_options = None
  _globals['_GETTHUMBNAILREQUEST'].fields_by_name['thumbnail_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['channel_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['episode_id']._loaded_options = None
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['episode_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['video_id']._loaded_options = None
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['video_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTHUMBNAILREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\007<=15000'
  _globals['_CREATETHUMBNAILREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_CREATETHUMBNAILREQUEST'].fields_by_name['channel_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATETHUMBNAILREQUEST'].fields_by_name['episode_id']._loaded_options = None
  _globals['_CREATETHUMBNAILREQUEST'].fields_by_name['episode_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATETHUMBNAILREQUEST'].fields_by_name['video_id']._loaded_options = None
  _globals['_CREATETHUMBNAILREQUEST'].fields_by_name['video_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_BATCHGENERATEDOWNLOADURLSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_BATCHGENERATEDOWNLOADURLSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BATCHGENERATEDOWNLOADURLSREQUEST'].fields_by_name['thumbnail_ids']._loaded_options = None
  _globals['_BATCHGENERATEDOWNLOADURLSREQUEST'].fields_by_name['thumbnail_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _globals['_GENERATETHUMBNAILUPLOADURLREQUEST'].fields_by_name['thumbnail_id']._loaded_options = None
  _globals['_GENERATETHUMBNAILUPLOADURLREQUEST'].fields_by_name['thumbnail_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETETHUMBNAILREQUEST'].fields_by_name['thumbnail_id']._loaded_options = None
  _globals['_DELETETHUMBNAILREQUEST'].fields_by_name['thumbnail_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_THUMBNAILSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_THUMBNAILSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/video/v1/thumbnails/{thumbnail_id}'
  _globals['_THUMBNAILSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_THUMBNAILSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/video/v1/thumbnails'
  _globals['_THUMBNAILSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_THUMBNAILSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateThumbnailMetadata\022\tThumbnail\202\323\344\223\002\031\"\024/video/v1/thumbnails:\001*'
  _globals['_THUMBNAILSERVICE'].methods_by_name['BatchGenerateDownloadURLs']._loaded_options = None
  _globals['_THUMBNAILSERVICE'].methods_by_name['BatchGenerateDownloadURLs']._serialized_options = b'\202\323\344\223\0023\"./video/v1/thumbnails:batchGenerateDownloadURLs:\001*'
  _globals['_THUMBNAILSERVICE'].methods_by_name['GenerateUploadURL']._loaded_options = None
  _globals['_THUMBNAILSERVICE'].methods_by_name['GenerateUploadURL']._serialized_options = b'\202\323\344\223\002:\"5/video/v1/thumbnails/{thumbnail_id}:generateUploadURL:\001*'
  _globals['_THUMBNAILSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_THUMBNAILSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteThumbnailMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/video/v1/thumbnails/{thumbnail_id}'
  _globals['_GETTHUMBNAILREQUEST']._serialized_start=246
  _globals['_GETTHUMBNAILREQUEST']._serialized_end=303
  _globals['_LISTTHUMBNAILREQUEST']._serialized_start=306
  _globals['_LISTTHUMBNAILREQUEST']._serialized_end=511
  _globals['_LISTTHUMBNAILRESPONSE']._serialized_start=513
  _globals['_LISTTHUMBNAILRESPONSE']._serialized_end=621
  _globals['_CREATETHUMBNAILREQUEST']._serialized_start=624
  _globals['_CREATETHUMBNAILREQUEST']._serialized_end=762
  _globals['_CREATETHUMBNAILMETADATA']._serialized_start=764
  _globals['_CREATETHUMBNAILMETADATA']._serialized_end=811
  _globals['_BATCHGENERATEDOWNLOADURLSREQUEST']._serialized_start=813
  _globals['_BATCHGENERATEDOWNLOADURLSREQUEST']._serialized_end=923
  _globals['_BATCHGENERATEDOWNLOADURLSRESPONSE']._serialized_start=925
  _globals['_BATCHGENERATEDOWNLOADURLSRESPONSE']._serialized_end=1028
  _globals['_THUMBNAILDOWNLOADURL']._serialized_start=1031
  _globals['_THUMBNAILDOWNLOADURL']._serialized_end=1383
  _globals['_THUMBNAILDOWNLOADURL_SCALEDURL']._serialized_start=1176
  _globals['_THUMBNAILDOWNLOADURL_SCALEDURL']._serialized_end=1318
  _globals['_THUMBNAILDOWNLOADURL_IMAGEFORMAT']._serialized_start=1320
  _globals['_THUMBNAILDOWNLOADURL_IMAGEFORMAT']._serialized_end=1383
  _globals['_GENERATETHUMBNAILUPLOADURLREQUEST']._serialized_start=1385
  _globals['_GENERATETHUMBNAILUPLOADURLREQUEST']._serialized_end=1456
  _globals['_GENERATETHUMBNAILUPLOADURLRESPONSE']._serialized_start=1458
  _globals['_GENERATETHUMBNAILUPLOADURLRESPONSE']._serialized_end=1514
  _globals['_DELETETHUMBNAILREQUEST']._serialized_start=1516
  _globals['_DELETETHUMBNAILREQUEST']._serialized_end=1576
  _globals['_DELETETHUMBNAILMETADATA']._serialized_start=1578
  _globals['_DELETETHUMBNAILMETADATA']._serialized_end=1625
  _globals['_THUMBNAILSERVICE']._serialized_start=1628
  _globals['_THUMBNAILSERVICE']._serialized_end=2671
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResourcePreset(google.protobuf.message.Message):
    """A preset of resources for hardware configuration of SQL Server hosts."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ZONE_IDS_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the resource preset."""
    cores: builtins.int
    """Number of CPU cores for an SQL Server host created with the preset."""
    memory: builtins.int
    """RAM volume for an SQL Server host created with the preset, in bytes."""
    @property
    def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of availability zones where the resource preset is available."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
        cores: builtins.int = ...,
        memory: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cores", b"cores", "id", b"id", "memory", b"memory", "zone_ids", b"zone_ids"]) -> None: ...

global___ResourcePreset = ResourcePreset



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v2/community.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v2/community.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/datasphere/v2/community.proto\x12\x1ayandex.cloud.datasphere.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x02\n\tCommunity\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x41\n\x06labels\x18\x05 \x03(\x0b\x32\x31.yandex.cloud.datasphere.v2.Community.LabelsEntry\x12\x15\n\rcreated_by_id\x18\x06 \x01(\t\x12\x17\n\x0forganization_id\x18\n \x01(\t\x12\x0f\n\x07zone_id\x18\x0b \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\nBk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.community_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _globals['_COMMUNITY_LABELSENTRY']._loaded_options = None
  _globals['_COMMUNITY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_COMMUNITY']._serialized_start=108
  _globals['_COMMUNITY']._serialized_end=399
  _globals['_COMMUNITY_LABELSENTRY']._serialized_start=348
  _globals['_COMMUNITY_LABELSENTRY']._serialized_end=393
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/broker/v1/broker_data_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/broker/v1/broker_data_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/iot/broker/v1/broker_data_service.proto\x12\x1ayandex.cloud.iot.broker.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"v\n\x18PublishBrokerDataRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05topic\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x1a\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\x0c\x8a\xc8\x31\x08<=262144\"\x1b\n\x19PublishBrokerDataResponse2\xc3\x01\n\x11\x42rokerDataService\x12\xad\x01\n\x07Publish\x12\x34.yandex.cloud.iot.broker.v1.PublishBrokerDataRequest\x1a\x35.yandex.cloud.iot.broker.v1.PublishBrokerDataResponse\"5\x82\xd3\xe4\x93\x02/\"*/iot-broker/v1/brokers/{broker_id}/publish:\x01*Bg\n\x1eyandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;brokerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.broker.v1.broker_data_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;broker'
  _globals['_PUBLISHBROKERDATAREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_PUBLISHBROKERDATAREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PUBLISHBROKERDATAREQUEST'].fields_by_name['topic']._loaded_options = None
  _globals['_PUBLISHBROKERDATAREQUEST'].fields_by_name['topic']._serialized_options = b'\350\3071\001\212\3101\006<=1024'
  _globals['_PUBLISHBROKERDATAREQUEST'].fields_by_name['data']._loaded_options = None
  _globals['_PUBLISHBROKERDATAREQUEST'].fields_by_name['data']._serialized_options = b'\212\3101\010<=262144'
  _globals['_BROKERDATASERVICE'].methods_by_name['Publish']._loaded_options = None
  _globals['_BROKERDATASERVICE'].methods_by_name['Publish']._serialized_options = b'\202\323\344\223\002/\"*/iot-broker/v1/brokers/{broker_id}/publish:\001*'
  _globals['_PUBLISHBROKERDATAREQUEST']._serialized_start=145
  _globals['_PUBLISHBROKERDATAREQUEST']._serialized_end=263
  _globals['_PUBLISHBROKERDATARESPONSE']._serialized_start=265
  _globals['_PUBLISHBROKERDATARESPONSE']._serialized_end=292
  _globals['_BROKERDATASERVICE']._serialized_start=295
  _globals['_BROKERDATASERVICE']._serialized_end=490
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.workflows.v1.workflow_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateWorkflowRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SPECIFICATION_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    EXPRESS_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create Workflow in."""
    name: builtins.str
    """Name of Workflow.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of Workflow."""
    network_id: builtins.str
    """ID of the VPC network Workflow will be executed in, in order to access private resources."""
    service_account_id: builtins.str
    """ID of the Service Account which will be used for resources access in Workflow execution."""
    express: builtins.bool
    """Express execution mode."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Workflow labels as `key:value` pairs."""

    @property
    def specification(self) -> yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowSpecification:
        """Specification of Workflow"""

    @property
    def log_options(self) -> yandex.cloud.serverless.workflows.v1.workflow_pb2.LogOptions:
        """Options for logging from Workflow."""

    @property
    def schedule(self) -> yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowSchedule:
        """Workflow schedule settings."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        specification: yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowSpecification | None = ...,
        log_options: yandex.cloud.serverless.workflows.v1.workflow_pb2.LogOptions | None = ...,
        network_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
        express: builtins.bool = ...,
        schedule: yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowSchedule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["log_options", b"log_options", "schedule", b"schedule", "specification", b"specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "express", b"express", "folder_id", b"folder_id", "labels", b"labels", "log_options", b"log_options", "name", b"name", "network_id", b"network_id", "schedule", b"schedule", "service_account_id", b"service_account_id", "specification", b"specification"]) -> None: ...

global___CreateWorkflowRequest = CreateWorkflowRequest

@typing.final
class CreateWorkflowMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["workflow_id", b"workflow_id"]) -> None: ...

global___CreateWorkflowMetadata = CreateWorkflowMetadata

@typing.final
class UpdateWorkflowRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SPECIFICATION_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    EXPRESS_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    name: builtins.str
    """Name of the Workflow. The name is unique within the folder."""
    description: builtins.str
    """Description of the Workflow."""
    network_id: builtins.str
    """ID of the VPC network Workflow will be executed in, in order to access private resources."""
    service_account_id: builtins.str
    """ID of the Service Account which will be used for resources access in Workflow execution."""
    express: builtins.bool
    """Express execution mode."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Workflow labels as `key:value` pairs."""

    @property
    def specification(self) -> yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowSpecification:
        """Specification of the Workflow."""

    @property
    def log_options(self) -> yandex.cloud.serverless.workflows.v1.workflow_pb2.LogOptions:
        """Options for logging from the Workflow."""

    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Workflow should be updated."""

    @property
    def schedule(self) -> yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowSchedule:
        """Workflow schedule settings."""

    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        specification: yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowSpecification | None = ...,
        log_options: yandex.cloud.serverless.workflows.v1.workflow_pb2.LogOptions | None = ...,
        network_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        express: builtins.bool = ...,
        schedule: yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowSchedule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["log_options", b"log_options", "schedule", b"schedule", "specification", b"specification", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "express", b"express", "labels", b"labels", "log_options", b"log_options", "name", b"name", "network_id", b"network_id", "schedule", b"schedule", "service_account_id", b"service_account_id", "specification", b"specification", "update_mask", b"update_mask", "workflow_id", b"workflow_id"]) -> None: ...

global___UpdateWorkflowRequest = UpdateWorkflowRequest

@typing.final
class UpdateWorkflowMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["workflow_id", b"workflow_id"]) -> None: ...

global___UpdateWorkflowMetadata = UpdateWorkflowMetadata

@typing.final
class GetWorkflowRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["workflow_id", b"workflow_id"]) -> None: ...

global___GetWorkflowRequest = GetWorkflowRequest

@typing.final
class GetWorkflowResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_FIELD_NUMBER: builtins.int
    @property
    def workflow(self) -> yandex.cloud.serverless.workflows.v1.workflow_pb2.Workflow:
        """Workflow properties."""

    def __init__(
        self,
        *,
        workflow: yandex.cloud.serverless.workflows.v1.workflow_pb2.Workflow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["workflow", b"workflow"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["workflow", b"workflow"]) -> None: ...

global___GetWorkflowResponse = GetWorkflowResponse

@typing.final
class DeleteWorkflowRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["workflow_id", b"workflow_id"]) -> None: ...

global___DeleteWorkflowRequest = DeleteWorkflowRequest

@typing.final
class DeleteWorkflowMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow."""
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["workflow_id", b"workflow_id"]) -> None: ...

global___DeleteWorkflowMetadata = DeleteWorkflowMetadata

@typing.final
class ListWorkflowsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list Workflows in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `pageSize`, the service returns a [ListWorkflowsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListWorkflowsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters functions listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to following fields: name, created_at.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z]([-a-z0-9]{0,61}[a-z0-9])?`.
    Example of a filter: `name=my-workflow`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListWorkflowsRequest = ListWorkflowsRequest

@typing.final
class ListWorkflowsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOWS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListWorkflowsRequest.page_size], use `next_page_token` as the value
    for the [ListWorkflowsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def workflows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowPreview]:
        """List of Workflows."""

    def __init__(
        self,
        *,
        workflows: collections.abc.Iterable[yandex.cloud.serverless.workflows.v1.workflow_pb2.WorkflowPreview] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "workflows", b"workflows"]) -> None: ...

global___ListWorkflowsResponse = ListWorkflowsResponse

@typing.final
class ListOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `pageSize`, the service returns a [ListOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `pageToken` to the
    [ListOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the [operation.Operation.done], [operation.Operation.created_by] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Examples of a filter: `done=false`, `created_by='John.Doe'`.
    """
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "workflow_id", b"workflow_id"]) -> None: ...

global___ListOperationsRequest = ListOperationsRequest

@typing.final
class ListOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified Workflow."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListOperationsResponse = ListOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _UnitFormat:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UnitFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UnitFormat.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNIT_FORMAT_UNSPECIFIED: _UnitFormat.ValueType  # 0
    UNIT_NONE: _UnitFormat.ValueType  # 1
    """Misc.

    None (show tick values as-is).
    """
    UNIT_COUNT: _UnitFormat.ValueType  # 2
    """Count."""
    UNIT_PERCENT: _UnitFormat.ValueType  # 3
    """Percent (0-100)."""
    UNIT_PERCENT_UNIT: _UnitFormat.ValueType  # 4
    """Percent (0-1)."""
    UNIT_NANOSECONDS: _UnitFormat.ValueType  # 5
    """Time.

    Nanoseconds (ns).
    """
    UNIT_MICROSECONDS: _UnitFormat.ValueType  # 6
    """Microseconds (µs)."""
    UNIT_MILLISECONDS: _UnitFormat.ValueType  # 7
    """Milliseconds (ms)."""
    UNIT_SECONDS: _UnitFormat.ValueType  # 8
    """Seconds (s)."""
    UNIT_MINUTES: _UnitFormat.ValueType  # 9
    """Minutes (m)."""
    UNIT_HOURS: _UnitFormat.ValueType  # 10
    """Hours (h)."""
    UNIT_DAYS: _UnitFormat.ValueType  # 11
    """Days (d)."""
    UNIT_BITS_SI: _UnitFormat.ValueType  # 12
    """Data (SI).

    Bits (SI).
    """
    UNIT_BYTES_SI: _UnitFormat.ValueType  # 13
    """Bytes (SI)."""
    UNIT_KILOBYTES: _UnitFormat.ValueType  # 14
    """Kilobytes (KB)."""
    UNIT_MEGABYTES: _UnitFormat.ValueType  # 15
    """Megabytes (MB)."""
    UNIT_GIGABYTES: _UnitFormat.ValueType  # 16
    """Gigabytes (GB)."""
    UNIT_TERABYTES: _UnitFormat.ValueType  # 17
    """Terabytes (TB)"""
    UNIT_PETABYTES: _UnitFormat.ValueType  # 18
    """Petabytes (PB)."""
    UNIT_EXABYTES: _UnitFormat.ValueType  # 19
    """Exabytes (EB)."""
    UNIT_BITS_IEC: _UnitFormat.ValueType  # 20
    """Data (IEC).

    Bits (IEC).
    """
    UNIT_BYTES_IEC: _UnitFormat.ValueType  # 21
    """Bytes (IEC)."""
    UNIT_KIBIBYTES: _UnitFormat.ValueType  # 22
    """Kibibytes (KiB)."""
    UNIT_MEBIBYTES: _UnitFormat.ValueType  # 23
    """Mebibytes (MiB)."""
    UNIT_GIBIBYTES: _UnitFormat.ValueType  # 24
    """Gigibytes (GiB)."""
    UNIT_TEBIBYTES: _UnitFormat.ValueType  # 25
    """Tebibytes (TiB)."""
    UNIT_PEBIBYTES: _UnitFormat.ValueType  # 26
    """Pebibytes (PiB)."""
    UNIT_EXBIBYTES: _UnitFormat.ValueType  # 27
    """Exbibytes (EiB)."""
    UNIT_REQUESTS_PER_SECOND: _UnitFormat.ValueType  # 28
    """Throughput.

    Requests per second (reqps).
    """
    UNIT_OPERATIONS_PER_SECOND: _UnitFormat.ValueType  # 29
    """Operations per second (ops)."""
    UNIT_WRITES_PER_SECOND: _UnitFormat.ValueType  # 30
    """Writes per second (wps)."""
    UNIT_READS_PER_SECOND: _UnitFormat.ValueType  # 31
    """Reads per second (rps)."""
    UNIT_PACKETS_PER_SECOND: _UnitFormat.ValueType  # 32
    """Packets per second (pps)."""
    UNIT_IO_OPERATIONS_PER_SECOND: _UnitFormat.ValueType  # 33
    """IO operations per second (iops)."""
    UNIT_COUNTS_PER_SECOND: _UnitFormat.ValueType  # 34
    """Counts per second (counts/sec)."""
    UNIT_BITS_SI_PER_SECOND: _UnitFormat.ValueType  # 35
    """Data Rate (SI).

    Bits (SI) per second (bits/sec).
    """
    UNIT_BYTES_SI_PER_SECOND: _UnitFormat.ValueType  # 36
    """Bytes (SI) per second (bytes/sec)."""
    UNIT_KILOBITS_PER_SECOND: _UnitFormat.ValueType  # 37
    """Kilobits per second (KBits/sec)."""
    UNIT_KILOBYTES_PER_SECOND: _UnitFormat.ValueType  # 38
    """Kilobytes per second (KB/sec)."""
    UNIT_MEGABITS_PER_SECOND: _UnitFormat.ValueType  # 39
    """Megabits per second (MBits/sec)."""
    UNIT_MEGABYTES_PER_SECOND: _UnitFormat.ValueType  # 40
    """Megabytes per second (MB/sec)."""
    UNIT_GIGABITS_PER_SECOND: _UnitFormat.ValueType  # 41
    """Gigabits per second (GBits/sec)."""
    UNIT_GIGABYTES_PER_SECOND: _UnitFormat.ValueType  # 42
    """Gigabytes per second (GB/sec)."""
    UNIT_TERABITS_PER_SECOND: _UnitFormat.ValueType  # 43
    """Terabits per second (TBits/sec)."""
    UNIT_TERABYTES_PER_SECOND: _UnitFormat.ValueType  # 44
    """Terabytes per second (TB/sec)."""
    UNIT_PETABITS_PER_SECOND: _UnitFormat.ValueType  # 45
    """Petabits per second (Pbits/sec)."""
    UNIT_PETABYTES_PER_SECOND: _UnitFormat.ValueType  # 46
    """Petabytes per second (PB/sec)."""
    UNIT_BITS_IEC_PER_SECOND: _UnitFormat.ValueType  # 47
    """Data Rate (IEC).

    Bits (IEC) per second (bits/sec).
    """
    UNIT_BYTES_IEC_PER_SECOND: _UnitFormat.ValueType  # 48
    """Bytes (IEC) per second (bytes/sec)."""
    UNIT_KIBIBITS_PER_SECOND: _UnitFormat.ValueType  # 49
    """Kibibits per second (KiBits/sec)."""
    UNIT_KIBIBYTES_PER_SECOND: _UnitFormat.ValueType  # 50
    """Kibibytes per second (KiB/sec)."""
    UNIT_MEBIBITS_PER_SECOND: _UnitFormat.ValueType  # 51
    """Mebibits per second (MiBits/sec)."""
    UNIT_MEBIBYTES_PER_SECOND: _UnitFormat.ValueType  # 52
    """Mebibytes per second (MiB/sec)."""
    UNIT_GIBIBITS_PER_SECOND: _UnitFormat.ValueType  # 53
    """Gibibits per second (GiBits/sec)."""
    UNIT_GIBIBYTES_PER_SECOND: _UnitFormat.ValueType  # 54
    """Gibibytes per second (GiB/sec)."""
    UNIT_TEBIBITS_PER_SECOND: _UnitFormat.ValueType  # 55
    """Tebibits per second (TiBits/sec)."""
    UNIT_TEBIBYTES_PER_SECOND: _UnitFormat.ValueType  # 56
    """Tebibytes per second (TiB/sec)."""
    UNIT_PEBIBITS_PER_SECOND: _UnitFormat.ValueType  # 57
    """Pebibits per second (PiBits/sec)."""
    UNIT_PEBIBYTES_PER_SECOND: _UnitFormat.ValueType  # 58
    """Pebibytes per second (PiB/sec)."""
    UNIT_DATETIME_UTC: _UnitFormat.ValueType  # 59
    """Date & time.

    Datetime (UTC).
    """
    UNIT_DATETIME_LOCAL: _UnitFormat.ValueType  # 60
    """Datetime (local)."""
    UNIT_HERTZ: _UnitFormat.ValueType  # 61
    """Frequency.

    Hertz (Hz).
    """
    UNIT_KILOHERTZ: _UnitFormat.ValueType  # 62
    """Kilohertz (KHz)."""
    UNIT_MEGAHERTZ: _UnitFormat.ValueType  # 63
    """Megahertz (MHz)."""
    UNIT_GIGAHERTZ: _UnitFormat.ValueType  # 64
    """Gigahertz (GHz)."""
    UNIT_DOLLAR: _UnitFormat.ValueType  # 65
    """Currency.

    Dollar.
    """
    UNIT_EURO: _UnitFormat.ValueType  # 66
    """Euro."""
    UNIT_ROUBLE: _UnitFormat.ValueType  # 67
    """Rouble."""
    UNIT_CELSIUS: _UnitFormat.ValueType  # 68
    """Temperature.

    Celsius (°C).
    """
    UNIT_FAHRENHEIT: _UnitFormat.ValueType  # 69
    """Fahrenheit (°F)."""
    UNIT_KELVIN: _UnitFormat.ValueType  # 70
    """Kelvin (K)."""
    UNIT_FLOP_PER_SECOND: _UnitFormat.ValueType  # 71
    """Computation.

    Flop per second (FLOP/sec).
    """
    UNIT_KILOFLOP_PER_SECOND: _UnitFormat.ValueType  # 72
    """Kiloflop per second (KFLOP/sec)."""
    UNIT_MEGAFLOP_PER_SECOND: _UnitFormat.ValueType  # 73
    """Megaflop per second (MFLOP/sec)."""
    UNIT_GIGAFLOP_PER_SECOND: _UnitFormat.ValueType  # 74
    """Gigaflop per second (GFLOP/sec)."""
    UNIT_PETAFLOP_PER_SECOND: _UnitFormat.ValueType  # 75
    """Petaflop per second (PFLOP/sec)."""
    UNIT_EXAFLOP_PER_SECOND: _UnitFormat.ValueType  # 76
    """Exaflop per second (EFLOP/sec)."""
    UNIT_METERS_PER_SECOND: _UnitFormat.ValueType  # 77
    """Velocity.

    Meters per second (m/sec).
    """
    UNIT_KILOMETERS_PER_HOUR: _UnitFormat.ValueType  # 78
    """Kilometers per hour (km/h)."""
    UNIT_MILES_PER_HOUR: _UnitFormat.ValueType  # 79
    """Miles per hour (mi/h)."""
    UNIT_MILLIMETER: _UnitFormat.ValueType  # 80
    """Length.

    Millimeter.
    """
    UNIT_CENTIMETER: _UnitFormat.ValueType  # 81
    """Centimeter."""
    UNIT_METER: _UnitFormat.ValueType  # 82
    """Meter."""
    UNIT_KILOMETER: _UnitFormat.ValueType  # 83
    """Kilometer."""
    UNIT_MILE: _UnitFormat.ValueType  # 84
    """Mile."""
    UNIT_PPM: _UnitFormat.ValueType  # 85
    """Concentration.

    Parts per million (ppm).
    """
    UNIT_EVENTS_PER_SECOND: _UnitFormat.ValueType  # 86
    """Events per second"""
    UNIT_PACKETS: _UnitFormat.ValueType  # 87
    """Packets"""
    UNIT_DBM: _UnitFormat.ValueType  # 88
    """dBm (dbm)"""
    UNIT_VIRTUAL_CPU: _UnitFormat.ValueType  # 89
    """Virtual CPU cores based on CPU time (vcpu)"""
    UNIT_MESSAGES_PER_SECOND: _UnitFormat.ValueType  # 90
    """Messages per second (mps)"""
    UNIT_NANOCORE_CPU: _UnitFormat.ValueType  # 91
    """== UNIT_VIRTUAL_CPU"""
    UNIT_MICROCORE_CPU: _UnitFormat.ValueType  # 92
    """== 1000 UNIT_NANOCORE_CPU"""
    UNIT_MILLICORE_CPU: _UnitFormat.ValueType  # 93
    """== 1000 UNIT_MICROCORE_CPU"""
    UNIT_CORE_CPU: _UnitFormat.ValueType  # 94
    """== 1000 UNIT_MILLICORE_CPU"""

class UnitFormat(_UnitFormat, metaclass=_UnitFormatEnumTypeWrapper): ...

UNIT_FORMAT_UNSPECIFIED: UnitFormat.ValueType  # 0
UNIT_NONE: UnitFormat.ValueType  # 1
"""Misc.

None (show tick values as-is).
"""
UNIT_COUNT: UnitFormat.ValueType  # 2
"""Count."""
UNIT_PERCENT: UnitFormat.ValueType  # 3
"""Percent (0-100)."""
UNIT_PERCENT_UNIT: UnitFormat.ValueType  # 4
"""Percent (0-1)."""
UNIT_NANOSECONDS: UnitFormat.ValueType  # 5
"""Time.

Nanoseconds (ns).
"""
UNIT_MICROSECONDS: UnitFormat.ValueType  # 6
"""Microseconds (µs)."""
UNIT_MILLISECONDS: UnitFormat.ValueType  # 7
"""Milliseconds (ms)."""
UNIT_SECONDS: UnitFormat.ValueType  # 8
"""Seconds (s)."""
UNIT_MINUTES: UnitFormat.ValueType  # 9
"""Minutes (m)."""
UNIT_HOURS: UnitFormat.ValueType  # 10
"""Hours (h)."""
UNIT_DAYS: UnitFormat.ValueType  # 11
"""Days (d)."""
UNIT_BITS_SI: UnitFormat.ValueType  # 12
"""Data (SI).

Bits (SI).
"""
UNIT_BYTES_SI: UnitFormat.ValueType  # 13
"""Bytes (SI)."""
UNIT_KILOBYTES: UnitFormat.ValueType  # 14
"""Kilobytes (KB)."""
UNIT_MEGABYTES: UnitFormat.ValueType  # 15
"""Megabytes (MB)."""
UNIT_GIGABYTES: UnitFormat.ValueType  # 16
"""Gigabytes (GB)."""
UNIT_TERABYTES: UnitFormat.ValueType  # 17
"""Terabytes (TB)"""
UNIT_PETABYTES: UnitFormat.ValueType  # 18
"""Petabytes (PB)."""
UNIT_EXABYTES: UnitFormat.ValueType  # 19
"""Exabytes (EB)."""
UNIT_BITS_IEC: UnitFormat.ValueType  # 20
"""Data (IEC).

Bits (IEC).
"""
UNIT_BYTES_IEC: UnitFormat.ValueType  # 21
"""Bytes (IEC)."""
UNIT_KIBIBYTES: UnitFormat.ValueType  # 22
"""Kibibytes (KiB)."""
UNIT_MEBIBYTES: UnitFormat.ValueType  # 23
"""Mebibytes (MiB)."""
UNIT_GIBIBYTES: UnitFormat.ValueType  # 24
"""Gigibytes (GiB)."""
UNIT_TEBIBYTES: UnitFormat.ValueType  # 25
"""Tebibytes (TiB)."""
UNIT_PEBIBYTES: UnitFormat.ValueType  # 26
"""Pebibytes (PiB)."""
UNIT_EXBIBYTES: UnitFormat.ValueType  # 27
"""Exbibytes (EiB)."""
UNIT_REQUESTS_PER_SECOND: UnitFormat.ValueType  # 28
"""Throughput.

Requests per second (reqps).
"""
UNIT_OPERATIONS_PER_SECOND: UnitFormat.ValueType  # 29
"""Operations per second (ops)."""
UNIT_WRITES_PER_SECOND: UnitFormat.ValueType  # 30
"""Writes per second (wps)."""
UNIT_READS_PER_SECOND: UnitFormat.ValueType  # 31
"""Reads per second (rps)."""
UNIT_PACKETS_PER_SECOND: UnitFormat.ValueType  # 32
"""Packets per second (pps)."""
UNIT_IO_OPERATIONS_PER_SECOND: UnitFormat.ValueType  # 33
"""IO operations per second (iops)."""
UNIT_COUNTS_PER_SECOND: UnitFormat.ValueType  # 34
"""Counts per second (counts/sec)."""
UNIT_BITS_SI_PER_SECOND: UnitFormat.ValueType  # 35
"""Data Rate (SI).

Bits (SI) per second (bits/sec).
"""
UNIT_BYTES_SI_PER_SECOND: UnitFormat.ValueType  # 36
"""Bytes (SI) per second (bytes/sec)."""
UNIT_KILOBITS_PER_SECOND: UnitFormat.ValueType  # 37
"""Kilobits per second (KBits/sec)."""
UNIT_KILOBYTES_PER_SECOND: UnitFormat.ValueType  # 38
"""Kilobytes per second (KB/sec)."""
UNIT_MEGABITS_PER_SECOND: UnitFormat.ValueType  # 39
"""Megabits per second (MBits/sec)."""
UNIT_MEGABYTES_PER_SECOND: UnitFormat.ValueType  # 40
"""Megabytes per second (MB/sec)."""
UNIT_GIGABITS_PER_SECOND: UnitFormat.ValueType  # 41
"""Gigabits per second (GBits/sec)."""
UNIT_GIGABYTES_PER_SECOND: UnitFormat.ValueType  # 42
"""Gigabytes per second (GB/sec)."""
UNIT_TERABITS_PER_SECOND: UnitFormat.ValueType  # 43
"""Terabits per second (TBits/sec)."""
UNIT_TERABYTES_PER_SECOND: UnitFormat.ValueType  # 44
"""Terabytes per second (TB/sec)."""
UNIT_PETABITS_PER_SECOND: UnitFormat.ValueType  # 45
"""Petabits per second (Pbits/sec)."""
UNIT_PETABYTES_PER_SECOND: UnitFormat.ValueType  # 46
"""Petabytes per second (PB/sec)."""
UNIT_BITS_IEC_PER_SECOND: UnitFormat.ValueType  # 47
"""Data Rate (IEC).

Bits (IEC) per second (bits/sec).
"""
UNIT_BYTES_IEC_PER_SECOND: UnitFormat.ValueType  # 48
"""Bytes (IEC) per second (bytes/sec)."""
UNIT_KIBIBITS_PER_SECOND: UnitFormat.ValueType  # 49
"""Kibibits per second (KiBits/sec)."""
UNIT_KIBIBYTES_PER_SECOND: UnitFormat.ValueType  # 50
"""Kibibytes per second (KiB/sec)."""
UNIT_MEBIBITS_PER_SECOND: UnitFormat.ValueType  # 51
"""Mebibits per second (MiBits/sec)."""
UNIT_MEBIBYTES_PER_SECOND: UnitFormat.ValueType  # 52
"""Mebibytes per second (MiB/sec)."""
UNIT_GIBIBITS_PER_SECOND: UnitFormat.ValueType  # 53
"""Gibibits per second (GiBits/sec)."""
UNIT_GIBIBYTES_PER_SECOND: UnitFormat.ValueType  # 54
"""Gibibytes per second (GiB/sec)."""
UNIT_TEBIBITS_PER_SECOND: UnitFormat.ValueType  # 55
"""Tebibits per second (TiBits/sec)."""
UNIT_TEBIBYTES_PER_SECOND: UnitFormat.ValueType  # 56
"""Tebibytes per second (TiB/sec)."""
UNIT_PEBIBITS_PER_SECOND: UnitFormat.ValueType  # 57
"""Pebibits per second (PiBits/sec)."""
UNIT_PEBIBYTES_PER_SECOND: UnitFormat.ValueType  # 58
"""Pebibytes per second (PiB/sec)."""
UNIT_DATETIME_UTC: UnitFormat.ValueType  # 59
"""Date & time.

Datetime (UTC).
"""
UNIT_DATETIME_LOCAL: UnitFormat.ValueType  # 60
"""Datetime (local)."""
UNIT_HERTZ: UnitFormat.ValueType  # 61
"""Frequency.

Hertz (Hz).
"""
UNIT_KILOHERTZ: UnitFormat.ValueType  # 62
"""Kilohertz (KHz)."""
UNIT_MEGAHERTZ: UnitFormat.ValueType  # 63
"""Megahertz (MHz)."""
UNIT_GIGAHERTZ: UnitFormat.ValueType  # 64
"""Gigahertz (GHz)."""
UNIT_DOLLAR: UnitFormat.ValueType  # 65
"""Currency.

Dollar.
"""
UNIT_EURO: UnitFormat.ValueType  # 66
"""Euro."""
UNIT_ROUBLE: UnitFormat.ValueType  # 67
"""Rouble."""
UNIT_CELSIUS: UnitFormat.ValueType  # 68
"""Temperature.

Celsius (°C).
"""
UNIT_FAHRENHEIT: UnitFormat.ValueType  # 69
"""Fahrenheit (°F)."""
UNIT_KELVIN: UnitFormat.ValueType  # 70
"""Kelvin (K)."""
UNIT_FLOP_PER_SECOND: UnitFormat.ValueType  # 71
"""Computation.

Flop per second (FLOP/sec).
"""
UNIT_KILOFLOP_PER_SECOND: UnitFormat.ValueType  # 72
"""Kiloflop per second (KFLOP/sec)."""
UNIT_MEGAFLOP_PER_SECOND: UnitFormat.ValueType  # 73
"""Megaflop per second (MFLOP/sec)."""
UNIT_GIGAFLOP_PER_SECOND: UnitFormat.ValueType  # 74
"""Gigaflop per second (GFLOP/sec)."""
UNIT_PETAFLOP_PER_SECOND: UnitFormat.ValueType  # 75
"""Petaflop per second (PFLOP/sec)."""
UNIT_EXAFLOP_PER_SECOND: UnitFormat.ValueType  # 76
"""Exaflop per second (EFLOP/sec)."""
UNIT_METERS_PER_SECOND: UnitFormat.ValueType  # 77
"""Velocity.

Meters per second (m/sec).
"""
UNIT_KILOMETERS_PER_HOUR: UnitFormat.ValueType  # 78
"""Kilometers per hour (km/h)."""
UNIT_MILES_PER_HOUR: UnitFormat.ValueType  # 79
"""Miles per hour (mi/h)."""
UNIT_MILLIMETER: UnitFormat.ValueType  # 80
"""Length.

Millimeter.
"""
UNIT_CENTIMETER: UnitFormat.ValueType  # 81
"""Centimeter."""
UNIT_METER: UnitFormat.ValueType  # 82
"""Meter."""
UNIT_KILOMETER: UnitFormat.ValueType  # 83
"""Kilometer."""
UNIT_MILE: UnitFormat.ValueType  # 84
"""Mile."""
UNIT_PPM: UnitFormat.ValueType  # 85
"""Concentration.

Parts per million (ppm).
"""
UNIT_EVENTS_PER_SECOND: UnitFormat.ValueType  # 86
"""Events per second"""
UNIT_PACKETS: UnitFormat.ValueType  # 87
"""Packets"""
UNIT_DBM: UnitFormat.ValueType  # 88
"""dBm (dbm)"""
UNIT_VIRTUAL_CPU: UnitFormat.ValueType  # 89
"""Virtual CPU cores based on CPU time (vcpu)"""
UNIT_MESSAGES_PER_SECOND: UnitFormat.ValueType  # 90
"""Messages per second (mps)"""
UNIT_NANOCORE_CPU: UnitFormat.ValueType  # 91
"""== UNIT_VIRTUAL_CPU"""
UNIT_MICROCORE_CPU: UnitFormat.ValueType  # 92
"""== 1000 UNIT_NANOCORE_CPU"""
UNIT_MILLICORE_CPU: UnitFormat.ValueType  # 93
"""== 1000 UNIT_MICROCORE_CPU"""
UNIT_CORE_CPU: UnitFormat.ValueType  # 94
"""== 1000 UNIT_MILLICORE_CPU"""
global___UnitFormat = UnitFormat



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/redis/v1/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/redis/v1/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/mdb/redis/v1/user.proto\x12\x19yandex.cloud.mdb.redis.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x8b\x01\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12;\n\x0bpermissions\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.redis.v1.Permissions\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61\x63l_options\x18\x05 \x01(\t\"\x8f\x02\n\x0bPermissions\x12.\n\x08patterns\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10pub_sub_channels\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ncategories\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x63ommands\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10sanitize_payload\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf0\x01\n\x08UserSpec\x12:\n\x04name\x18\x01 \x01(\tB,\xe8\xc7\x31\x01\xf2\xc7\x31\x1c^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\x8a\xc8\x31\x04<=32\x12>\n\tpasswords\x18\x02 \x03(\tB+\xf2\xc7\x31\x1e^[a-zA-Z0-9@=+?*.,!&#$^<>_-]*$\x82\xc8\x31\x01\x31\x90\xc8\x31\x01\x12;\n\x0bpermissions\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.redis.v1.Permissions\x12+\n\x07\x65nabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueBd\n\x1dyandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.redis.v1.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redis'
  _globals['_USERSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\034^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\212\3101\004<=32'
  _globals['_USERSPEC'].fields_by_name['passwords']._loaded_options = None
  _globals['_USERSPEC'].fields_by_name['passwords']._serialized_options = b'\362\3071\036^[a-zA-Z0-9@=+?*.,!&#$^<>_-]*$\202\3101\0011\220\3101\001'
  _globals['_USER']._serialized_start=131
  _globals['_USER']._serialized_end=270
  _globals['_PERMISSIONS']._serialized_start=273
  _globals['_PERMISSIONS']._serialized_end=544
  _globals['_USERSPEC']._serialized_start=547
  _globals['_USERSPEC']._serialized_end=787
# @@protoc_insertion_point(module_scope)
